<?php
/*------------------------------------------------------------------------
# urednideska.php - Úřední deska Component
# ------------------------------------------------------------------------
# author    Petr Houba
# copyright Copyright (C) 2013. All Rights Reserved
# license   GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
# website   urednideska.g6.cz
-------------------------------------------------------------------------*/

// No direct access to this file
defined('_JEXEC') or die('Restricted access');

// import the Joomla modellist library
jimport('joomla.application.component.modellist');
/**
 * Urednideska Model
 */
class UrednideskaModelUrednideska extends JModelList {
	
  /**
	 * Constructor.
	 *
	 * @param	array	An optional associative array of configuration settings.
	 * @see		JController
	 * @since	1.6
	 */
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'id', 'ud.id',
				'title', 'ud.title',
				'alias', 'ud.alias',
				'checked_out', 'ud.checked_out',
				'checked_out_time', 'ud.checked_out_time',
				'catid', 'ud.catid',
				'state', 'ud.state',
				'created', 'ud.created',
				'created_by', 'ud.created_by',
				'created_by_alias', 'ud.created_by_alias',
				'publish_up', 'ud.publish_up',
				'publish_down', 'ud.publish_down',
        'jedcislo', 'ud.jedcislo',
        'vlastni1', 'ud.vlastni1',
        'vlastni2', 'ud.vlastni2'
			);
		}

		parent::__construct($config);
	}
  
  
  /**
	 * Method to build an SQL query to load the list data.
	 *
	 * @return	string	An SQL query
	 */
	protected function getListQuery() {
		// Create a new query object.
		$db = JFactory::getDBO();
		$query = $db->getQuery(true);

		// Select some fields
		$query->select(
			$this->getState(
				'list.select',
				'ud.id, ud.title, ud.alias, ud.checked_out, ud.checked_out_time, ud.catid' .
				', ud.state, ud.created, ud.created_by, ud.publish_up, ud.publish_down, ud.jedcislo, ud.fulltext, ud.vlastni1, ud.vlastni2'
			)
		);
    
		// From the urednideska table
		$query->from('#__urednideska AS ud');
    
    // Join over the categories
		$query->select('k.title AS catitle');
		$query->join('LEFT', $db->quoteName('#__urednideska_kategorie').' AS k ON ud.catid = k.id');
    
    // Join over the users
		$query->select('u.name AS username');
		$query->join('LEFT', $db->quoteName('#__users').' AS u ON ud.created_by = u.id');
    
    // Join over the contacts
/*		$query->select('ko.name AS kontakt');
		$query->join('LEFT', $db->quoteName('#__contact_details').' AS ko ON ud.created_by_alias = ko.id'); */
    
    $query->where('k.published = 1 || ud.catid = 0');
    
    // Filter by search in title and item number.
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('ud.id = '.(int) substr($search, 3));
			}
			else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
				$query->where('(ud.title LIKE '.$search.' OR ud.jedcislo LIKE '.$search.')');
			}
		}
    
    // Filter by archive state
		$archive = $this->getState('filter.archive');
		if (is_numeric($archive)) {
			$query->where('ud.state = ' . (int) $archive);
		}
    
    // Filter by category
    $category = $this->getState('filter.category');
		if (is_numeric($category)) {
			$query->where('k.id = '.(int) $category);
		}
    
    // Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering', 'ud.publish_up');
		$orderDirn = $this->state->get('list.direction', 'asc');
    
    $query->order($db->escape($orderCol.' '.$orderDirn));

		return $query;
	}
  
  protected function populateState($ordering = null, $direction = null) {
		// Initialise variables.
		$app = JFactory::getApplication();
		$session = JFactory::getSession();

		// Adjust the context to support modal layouts.
		if ($layout = JRequest::getVar('layout')) {
			$this->context .= '.'.$layout;
		}

		$search = $this->getUserStateFromRequest($this->context.'.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		$anotace = $this->getUserStateFromRequest($this->context.'.filter.anotace', 'filter_anotace', 0, 'int');
		$this->setState('filter.anotace', $anotace);

		$archive = $this->getUserStateFromRequest($this->context.'.filter.archive', 'filter_archive', '');
		$this->setState('filter.archive', $archive);

		$category = $this->getUserStateFromRequest($this->context.'.filter.category', 'filter_category');
		$this->setState('filter.category', $category);

/*		$level = $this->getUserStateFromRequest($this->context.'.filter.level', 'filter_level', 0, 'int');
		$this->setState('filter.level', $level);


		$language = $this->getUserStateFromRequest($this->context.'.filter.language', 'filter_language', '');
		$this->setState('filter.language', $language);*/
    
    // Load the parameters.
		$params = JComponentHelper::getParams('com_urednideska');
		$this->setState('params', $params);

		// List state information.
		parent::populateState('ud.publish_up', 'asc');
	}
  
  /**
	 * Build a list of categories
	 *
	 * @return	JDatabaseQuery
	 */
	public function getCategories() {
		// Create a new query object.
		$db = $this->getDbo();
		$query = $db->getQuery(true);

		// Construct the query
		$query->select('k.id AS value, k.title AS text');
		$query->from('#__urednideska_kategorie AS k');
		$query->where('k.published = 1');
    $query->order('k.title');

		// Setup the query
		$db->setQuery($query->__toString());

		// Return the result
		return $db->loadObjectList();
	}
}
?>